@@ -24,6 +24,7 @@
 """Convert :term:`BAM` format to :term:`FASTQ` foarmat"""
 import os
 import subprocess
+from collections import Counter
 
 from bioconvert import ConvBase
 from bioconvert.core.decorators import requires
@@ -87,15 +88,12 @@ class BAM2FASTQ(ConvBase):
 
         data = []
         with open(self.outfile, "r") as fin:
-            count = 0
             for i in range(40000):
                 x = fin.readline()
                 if len(x) == 0:
                     break
                 data.append(x)
 
-        from collections import Counter
-
         isPaired = 2 in Counter([x for i, x in enumerate(data) if i % 4 == 0]).values()
         if isPaired:
             cmd = "bedtools bamtofastq -i {} -fq {}_1.{} -fq2 {}_2.{}".format(
@@ -117,8 +115,6 @@ class BAM2FASTQ(ConvBase):
         """Do the conversion :term:`BAM` -> :term:`FASTQ` using samtools
 
         `SAMtools documentation <http://www.htslib.org/doc/samtools.html>`_"""
-        cmd = "samtools fastq {} > {}".format(self.infile, self.outfile)
-        self.execute(cmd)
         # Test if input bam file is paired
         p = subprocess.Popen(
             "samtools view -c -f 1 {}".format(self.infile).split(),
