@@ -24,7 +24,7 @@
 """Download singularity image"""
 from os.path import exists
 
-from easydev import md5
+from bioconvert.core.utils import md5
 
 __all__ = ["download_singularity_image"]
 
