@@ -27,7 +27,7 @@ import csv
 import colorlog
 
 from bioconvert.core.base import ConvArg, ConvBase
-from bioconvert.core.decorators import compressor, in_gz, requires, requires_nothing
+from bioconvert.core.decorators import compressor, requires, requires_nothing
 
 logger = colorlog.getLogger(__name__)
 
@@ -100,7 +100,7 @@ class CSV2TSV(ConvBase):
         pd.read_csv(self.infile, sep=in_sep,).to_csv(
             self.outfile,
             sep=out_sep,
-            line_terminator=line_terminator,
+            lineterminator=line_terminator,
             index=False,
             header="infer",
         )
