@@ -28,7 +28,7 @@ import colorlog
 
 from bioconvert import ConvBase
 from bioconvert.core.base import ConvArg
-from bioconvert.core.decorators import requires, requires_nothing
+from bioconvert.core.decorators import requires
 
 logger = colorlog.getLogger(__name__)
 
