@@ -30,7 +30,7 @@ import colorlog
 
 from bioconvert import ConvBase
 from bioconvert.core.base import ConvArg
-from bioconvert.core.decorators import compressor, requires, requires_nothing
+from bioconvert.core.decorators import compressor, requires
 
 logger = colorlog.getLogger(__name__)
 
@@ -97,7 +97,7 @@ class XLS2CSV(ConvBase):
         df.to_csv(
             self.outfile,
             sep=out_sep,
-            line_terminator=line_terminator,
+            lineterminator=line_terminator,
             index=False,
             header="infer",
         )
